@@ -1,8 +1,7 @@
 class NavigationConfigGenerator < Rails::Generator::Base
   def manifest
     record do |m|
-      m.file "config/navigation.rb", "config/navigation.rb"
-      m.readme "../../../README"
+      m.file 'config/navigation.rb', 'config/navigation.rb'
     end
   end
-end
\ No newline at end of file
+end
