@@ -1,20 +1,18 @@
 module SimpleNavigation
   module Adapters
     class Padrino < Sinatra
-      
-      def self.register
-        SimpleNavigation.set_env(PADRINO_ROOT, PADRINO_ENV)
+      def self.register(app)
+        SimpleNavigation.set_env(::Padrino.root, ::Padrino.env)
         ::Padrino::Application.send(:helpers, SimpleNavigation::Helpers)
       end
-            
-      def link_to(name, url, options={})
+
+      def link_to(name, url, options = {})
         context.link_to(name, url, options)
       end
-      
-      def content_tag(type, content, options={})
+
+      def content_tag(type, content, options = {})
         context.content_tag(type, content.html_safe, options)
       end
-      
     end
   end
-end
\ No newline at end of file
+end
